==> lmtpd-0.9.19.tar.gz: lmtpd-0.9.19/version.c <==
/*
   Copyright 2000, 2001, 2002, 2003 Laurent Wacrenier

   This file is part of PLL lmtpd.

   PLL lmtpd is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   PLL lmtpd is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with PLL lmtpd; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#include "config.h"

#include <stdio.h>

#if WITH_PCRE
#include <pcre.h>
#endif

#if WITH_ONIGURUMA
#include <oniguruma.h>
#endif

#if WITH_DB
#include <db.h>
#endif

#if WITH_MYSQLLOG
#include <mysql_version.h>
#endif

#if HAVE_HOME_VERSION_H
#include <home_version.h>
#endif

#if HAVE_PATHS_H
#include <paths.h>
#endif

#if WITH_ICONV
#include <iconv.h>
#endif

#if WITH_PERL
#include <patchlevel.h>
#endif

#if WITH_TRE
#include <tre/tre-config.h>
#endif

#include "lmtp.h"

static char const rcsid[] = 
"$Id: version.c,v 1.21 2004/03/24 15:33:07 lwa Exp $";
static char const rcsid2[] = LMTP_H_RCSID;


#if WITH_ICONV
const char *const iconv_charset[] = 
  { "Utf-8", "Us-Ascii", 
    "Iso-8859-1", "Iso-8859-2", "Iso-8859-3", "Iso-8859-4",
    "Iso-8859-5", "Iso-8859-6", "Iso-8859-7", "Iso-8859-8",
    "Iso-8859-9", "Iso-8859-10", "Iso-8859-11", "Iso-8859-12",
    "Iso-8859-13", "Iso-8859-14", "Iso-8859-15", "Euc-Jp", "Big-5",
    "big5", "Gb2312", "Ks_C_5601-1987", "Euc-Kr",
    "x-user-defined", "unknown-8bit",
    "Windows-1251",
    "Windows-1252", "Cp1252", NULL };

static void iconv_test(void) {
  int i = 0;
  fprintf(stderr, "  testing some iconv supported conversions\n    ");
  while(iconv_charset[i]) {
    iconv_t di = iconv_open(iconv_charset[i], "UTF-8");
    fprintf(stderr, "%-14s ", iconv_charset[i]);
    if (di == (iconv_t)(-1)) {
      fprintf(stderr, "NO");
    } else {
      iconv_close(di);
      fprintf(stderr, "ok");
    }
    i++;
    if (iconv_charset[i]) {
      if (i%4 == 0) {
	fprintf(stderr, "\n    ");
      } else {
	fprintf(stderr, "  ");
      }
    }
  }
  fprintf(stderr, "\n");
}
#endif

void version (void) {
  fprintf(stderr, "lmtpd version " PACKAGE_VERSION "\n");
  fprintf(stderr, "compile date %s at %s\n", __DATE__, __TIME__);
#if WITH_MYSQLLOG
  fprintf(stderr, "compiled with MYSQL %s\n", MYSQL_SERVER_VERSION);
#endif
#if WITH_DB
  fprintf(stderr, "compiled with %s\n", DB_VERSION_STRING);
#endif
#if HAVE_LIBHOME
  fprintf(stderr, "compiled with libhome ");
#if HAVE_HOME_VERSION_H
  fprintf(stderr, "%s ", LIBHOME_VERSION);
#endif  
  fprintf(stderr, "support\n");
#endif
#if WITH_ICONV
  fprintf(stderr, "compiled with iconv\n");
#ifdef _LIBICONV_VERSION
  fprintf(stderr, "  lmtpd compile time iconv is libiconv %d.%d\n",
	  _LIBICONV_VERSION >> 8, _LIBICONV_VERSION & 0xff);
  fprintf(stderr, "  current libiconv is %d.%d\n",
	  _libiconv_version >> 8, _libiconv_version & 0xff);
#endif
  iconv_test();
#endif

#if WITH_PCRE
  fprintf(stderr, "compiled with PCRE %d.%d\n", PCRE_MAJOR, PCRE_MINOR);
  fprintf(stderr, "  current PCRE version %s\n", pcre_version());
#if HAVE_PCRE_CONFIG
#ifdef PCRE_CONFIG_UTF8
 {
     int pcre_with_utf8 = 0;
     pcre_config(PCRE_CONFIG_UTF8, &pcre_with_utf8);
     if (pcre_with_utf8) {
       fprintf(stderr, "  PCRE compiled with UTF-8 support\n");
     } else {
       fprintf(stderr, "  PCRE compiled without UTF-8 support\n");
     }
 }
#else 
  fprintf(stderr, "  this PCRE does not support UTF-8\n");
#endif
#endif
#endif

#if WITH_ONIGURUMA
  fprintf(stderr, "compiled with Oniguruma %d.%d.%d\n",
	  ONIGURUMA_VERSION_MAJOR
	  ONIGURUMA_VERSION_MINOR
	  ONIGURUMA_VERSION_TEENY);
  fprintf(stderr, "  current Oniguruma version %s\n", regex_version());
#endif

#if WITH_TRE
  fprintf(stderr, "compiled with TRE %s\n", TRE_VERSION);
  fprintf(stderr, "  checking TRE library load... ");
  {
    extern char *re_tre_init(void);
    char *err = re_tre_init();
    if (err == NULL)
      fprintf(stderr, "ok\n");
    else 
      fprintf(stderr, "failed: %s\n", err);
  }
#endif

#if WITH_REGEXP_DB_CACHE
  fprintf(stderr, "compiled with regexp DB cache\n");
#endif

#ifdef WITH_PERL
#ifdef PERL_REVISION
  fprintf(stderr, "compiled with perl %d.%d.%d\n",
	  PERL_REVISION, PERL_VERSION, PERL_SUBVERSION);
#else
  fprintf(stderr, "compiled with perl %d.%03d.%d\n",
	  5, PATCHLEVEL, SUBVERSION);
#endif
  fprintf(stderr, "default perl script %s\n", PERL_FILTER);
#endif
  fprintf(stderr, "default configuration file: %s\n", CONFFILE);
  fprintf(stderr, "higher score: " SCORE_FORMAT "\n", SCORE_MAX);
  fprintf(stderr, "default sendmail path %s\n", _PATH_SENDMAIL);
}

==> lmtpd-0.10.4.tar.gz: lmtpd-0.10.4/version.c <==
/*
   Copyright 2000, 2001, 2002, 2003 Laurent Wacrenier

   This file is part of PLL lmtpd.

   PLL lmtpd is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   PLL lmtpd is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with PLL lmtpd; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/


#include "config.h"
#include <stdio.h>

#if WITH_PCRE
#include <pcre.h>
#endif

#if WITH_ONIGURUMA
#include <oniguruma.h>
#endif

#if WITH_DB
#include <db.h>
#endif

#if WITH_MYSQLLOG
#include <mysql_version.h>
#endif

#if HAVE_HOME_VERSION_H
#include <home_version.h>
#endif

#if HAVE_PATHS_H
#include <paths.h>
#endif

#if WITH_ICONV
#include <iconv.h>
#endif

#if WITH_PERL
#include <patchlevel.h>
#endif

#if WITH_TRE
#include <tre/tre-config.h>
#endif

#include "lmtp.h"

#include "config.h"

static char const rcsid[] UNUSED = 
"$Id: version.c,v 1.23 2005/01/26 13:20:55 lwa Exp $";
static char const rcsid2[] UNUSED = LMTP_H_RCSID;


#if WITH_ICONV
const char *const iconv_charset[] = 
  { "Utf-8", "Us-Ascii", 
    "Iso-8859-1", "Iso-8859-2", "Iso-8859-3", "Iso-8859-4",
    "Iso-8859-5", "Iso-8859-6", "Iso-8859-7", "Iso-8859-8",
    "Iso-8859-9", "Iso-8859-10", "Iso-8859-11", "Iso-8859-12",
    "Iso-8859-13", "Iso-8859-14", "Iso-8859-15",
    "Iso-8859-16", "Euc-Jp", "Big-5",
    "big5", "Gb2312", "Ks_C_5601-1987", "Euc-Kr",
    "x-user-defined", "unknown-8bit",
    "Windows-1251",
    "Windows-1252", "Cp1252", NULL };

static void iconv_test(void) {
  int i = 0;
  fprintf(stderr, "  testing some iconv supported conversions\n    ");
  while(iconv_charset[i]) {
    iconv_t di = iconv_open(iconv_charset[i], "UTF-8");
    fprintf(stderr, "%-14s ", iconv_charset[i]);
    if (di == (iconv_t)(-1)) {
      fprintf(stderr, "NO");
    } else {
      iconv_close(di);
      fprintf(stderr, "ok");
    }
    i++;
    if (iconv_charset[i]) {
      if (i%4 == 0) {
	fprintf(stderr, "\n    ");
      } else {
	fprintf(stderr, "  ");
      }
    }
  }
  fprintf(stderr, "\n");
}
#endif

void version (void) {
  fprintf(stderr, "lmtpd version " PACKAGE_VERSION "\n");
  fprintf(stderr, "compile date %s at %s\n", __DATE__, __TIME__);
#if WITH_MYSQLLOG
  fprintf(stderr, "compiled with MYSQL %s\n", MYSQL_SERVER_VERSION);
#endif
#if WITH_DB
  fprintf(stderr, "compiled with %s\n", DB_VERSION_STRING);
#endif
#if HAVE_LIBHOME
  fprintf(stderr, "compiled with libhome ");
#if HAVE_HOME_VERSION_H
  fprintf(stderr, "%s ", LIBHOME_VERSION);
#endif  
  fprintf(stderr, "support\n");
#endif
#if WITH_ICONV
  fprintf(stderr, "compiled with iconv\n");
#ifdef _LIBICONV_VERSION
  fprintf(stderr, "  lmtpd compile time iconv is libiconv %d.%d\n",
	  _LIBICONV_VERSION >> 8, _LIBICONV_VERSION & 0xff);
  fprintf(stderr, "  current libiconv is %d.%d\n",
	  _libiconv_version >> 8, _libiconv_version & 0xff);
#endif
  iconv_test();
#endif

#if WITH_PCRE
  fprintf(stderr, "compiled with PCRE %d.%d\n", PCRE_MAJOR, PCRE_MINOR);
  fprintf(stderr, "  current PCRE version %s\n", pcre_version());
#if HAVE_PCRE_CONFIG
#ifdef PCRE_CONFIG_UTF8
 {
     int pcre_with_utf8 = 0;
     pcre_config(PCRE_CONFIG_UTF8, &pcre_with_utf8);
     if (pcre_with_utf8) {
       fprintf(stderr, "  PCRE compiled with UTF-8 support\n");
     } else {
       fprintf(stderr, "  PCRE compiled without UTF-8 support\n");
     }
 }
#else 
  fprintf(stderr, "  this PCRE does not support UTF-8\n");
#endif
#endif
#endif

#if WITH_ONIGURUMA
  fprintf(stderr, "compiled with Oniguruma %d.%d.%d\n",
	  ONIGURUMA_VERSION_MAJOR
	  ONIGURUMA_VERSION_MINOR
	  ONIGURUMA_VERSION_TEENY);
  fprintf(stderr, "  current Oniguruma version %s\n", regex_version());
#endif

#if WITH_TRE
  fprintf(stderr, "compiled with TRE %s\n", TRE_VERSION);
  fprintf(stderr, "  checking TRE library load... ");
  {
    extern char *re_tre_init(void);
    char *err = re_tre_init();
    if (err == NULL)
      fprintf(stderr, "ok\n");
    else 
      fprintf(stderr, "failed: %s\n", err);
  }
#endif

#if WITH_REGEXP_DB_CACHE
  fprintf(stderr, "compiled with regexp DB cache\n");
#endif

#ifdef WITH_PERL
#ifdef PERL_REVISION
  fprintf(stderr, "compiled with perl %d.%d.%d\n",
	  PERL_REVISION, PERL_VERSION, PERL_SUBVERSION);
#else
  fprintf(stderr, "compiled with perl %d.%03d.%d\n",
	  5, PATCHLEVEL, SUBVERSION);
#endif
  fprintf(stderr, "default perl script %s\n", PERL_FILTER);
#endif
  fprintf(stderr, "default configuration file: %s\n", CONFFILE);
  fprintf(stderr, "higher score: " SCORE_FORMAT "\n", SCORE_MAX);
  fprintf(stderr, "default sendmail path %s\n", _PATH_SENDMAIL);
}
